summaryrefslogtreecommitdiff
path: root/expt_0510.cu
diff options
context:
space:
mode:
authorKunoiSayami <[email protected]>2023-05-20 00:49:40 +0800
committerKunoiSayami <[email protected]>2023-05-20 00:49:40 +0800
commitbcfe8c96899cfda8df98e540d7d9147b6d8db2a0 (patch)
tree391fcf796a1225944cff67da1e6ca6afd52e7077 /expt_0510.cu
parentd38b99aba596b1a4edbc7e296f826d5ad936d357 (diff)
feat(exp): Add expt_0517
Signed-off-by: KunoiSayami <[email protected]>
Diffstat (limited to 'expt_0510.cu')
-rw-r--r--expt_0510.cu9
1 files changed, 4 insertions, 5 deletions
diff --git a/expt_0510.cu b/expt_0510.cu
index 3efad47..82f2624 100644
--- a/expt_0510.cu
+++ b/expt_0510.cu
@@ -15,7 +15,7 @@ constexpr size_t TEST_LENGTH = 32'768;
// constexpr size_t TEST_LENGTH = 4096;
// constexpr size_t RESERVED_BLOCK = 100;
-unsigned long long max_value = 0, min_value = 0xfffffffff;
+unsigned long long max_value = 0, min_value = 0xffffffffffff;
typedef std::pair<int, int> dim_pair_type;
inline void store_into_vector(unsigned long long value) {
@@ -61,8 +61,7 @@ __global__ void kernel(unsigned long step, const double slice_size) {
// printf("%d\n", tid);
auto _index = (int)(custom_sort.sample_cdf_custom_version(
- cudaSampleItem, cudaSampleItem + cuda_sample_length,
- cudaPopulationItem[tid]) /
+ cudaSampleItem, cudaPopulationItem[tid]) /
slice_size) -
1;
// cdf_result[index] = true;
@@ -224,7 +223,7 @@ int main(int argc, char const *argv[]) {
total_row = strtol(argv[3], nullptr, 10);
}
- CustomSort::testSelf(sample_length);
+ // CustomSort::testSelf(sample_length);
readFile("normal_distribution.txt", sample_length, total_row, test_size);
@@ -251,7 +250,7 @@ int main(int argc, char const *argv[]) {
// auto custom_sort = CustomSort(SAMPLE_LENGTH, sizeof(long) * 8);
// custom_sort.testCalculation();
applyCudaSampleLength<<<1, 1>>>(sample_length);
- testCustomCalculation<<<1, 1>>>(sample_length);
+ // testCustomCalculation<<<1, 1>>>(sample_length);
cudaDeviceSynchronize();
initSample<<<1, 1>>>(cudaSample, cudaPopulation);